@@ -19,7 +19,7 @@
 #
 
 package Thrift;
-our $VERSION = '0.6.1_01';
+our $VERSION = '0.8.0';
 
 require 5.6.0;
 use strict;
@@ -77,6 +77,8 @@ use constant INVALID_MESSAGE_TYPE => 2;
 use constant WRONG_METHOD_NAME    => 3;
 use constant BAD_SEQUENCE_ID      => 4;
 use constant MISSING_RESULT       => 5;
+use constant INTERNAL_ERROR       => 6;
+use constant PROTOCOL_ERROR       => 7;
 
 sub new {
     my $classname = shift;
